{{ Fly Sudoku 1.8

   (c) 2007 Rob Haskell (FlyingCucco)
   Portions of this program (c) 2006 Nurve Networks LLC
   Portions of this program (c) 2005-2007 Parallax, Inc.

  Uses
  "HEL_GFX_ENGINE_040"
  "Real_Random_012"
  "mouse_iso_010"
  "keyboard_iso_010"
  "spin_trig_010"

}}  
CON

  majorversion=1
  minorversion=8

  ' Propeller /////////////////////////////////////////////////////////////////////////////////

  _clkmode = xtal2 + pll8x       ' enable external clock range 5-10MHz and pll times 8
  _xinfreq = 10_000_000 + 0000   ' set frequency to 10 MHZ plus some error due to XTAL (1000-5000 usually works)
  _stack   = 128                 ' accomodate display memory and stack

VAR

  ' HEL_GFX /////////////////////////////////////////////////////////////////////////////////
  
  ' tile engine data structure pointers (can be changed in real-time by app!)
  long tile_map_base_ptr_parm       ' base address of the tile map
  long tile_bitmaps_base_ptr_parm   ' base address of the tile bitmaps
  long tile_palettes_base_ptr_parm  ' base address of the palettes

  long tile_map_sprite_cntrl_parm   ' pointer to the value that holds various "control" values for the tile map/sprite engine
                                    ' currently, encodes width of map, and number of sprites to process up to 8 in following format
                                    ' $xx_xx_ss_ww, xx is don't care/unused
                                    ' ss = number of sprites to process 1..8
                                    ' ww = the number of "screens" or multiples of 16 that the tile map is
                                    ' eg. 0 would be 16 wide (standard), 1 would be 32 tiles, 2 would be 64 tiles, etc.
                                    ' this allows multiscreen width playfields and thus large horizontal/vertical scrolling games
                                    ' note that the final size is always a power of 2 multiple of 16
   
  long tile_sprite_tbl_base_ptr_parm ' base address of sprite table
   
   
  ' real-time engine status variables, these are updated in real time by the
  ' tile engine itself, so they can be monitored outside in SPIN/ASM by game
  long tile_status_bits_parm      ' vsync, hsync, etc.
   
  ' format of tile_status_bits_parm, only the Vsync status bit is updated
  '
  ' byte 3 (unused)|byte 2 (line)|   byte 1 (tile postion)    |                     byte 0 (sync and region)      |
  '|x x x x x x x x| line 8-bits | row 4 bits | column 4-bits |x x x x | region 2-bits | hsync 1-bit | vsync 1-bit|
  '   b31..b24         b23..b16      b15..b12     b11..b8                    b3..b2          b1            b0
  ' Region 0=Top Overscan, 1=Active Video, 2=Bottom Overscan, 3=Vsync
  ' NOTE: In this version of the tile engine only VSYNC and REGION are valid 

  long sprites[16]
   
  ' Game /////////////////////////////////////////////////////////////////////////////////

  'state
  byte level
  
  'grid
  byte Grid[81]
  byte OriginalGrid[162]
  byte GridPoss[810]
  byte GridLock[81]

  'display
  word activetilemap[192]

  'mouse
  byte mousex
  byte mousey

  'cell selection
  byte cellx
  byte celly
                

OBJ

  gfx      : "HEL_GFX_ENGINE_040"
  rr       : "Real_Random_012"
  mouse    : "mouse_iso_010"
  keyboard : "keyboard_iso_010"
  trig     : "spin_trig_010"

PUB Main | x,y,i,n,k,tempcellx,tempcelly

  'Initialize Variables /////////////////////////////////////////////////////////////////////////////////

  'Graphics
  'points ptrs to actual memory storage for tile engine
  tile_map_base_ptr_parm        := @activetilemap
  tile_bitmaps_base_ptr_parm    := @tile_bitmaps
  tile_palettes_base_ptr_parm   := @palettes
  tile_map_sprite_cntrl_parm    := $00_00_03_00
                                ' set for 0 sprites and width 16 tiles (1 screens wide),
                                '0 = 16 tiles, 1 = 32 tiles, 2 = 64 tiles, 3 = 128 tiles, etc.
  tile_sprite_tbl_base_ptr_parm := @sprites 
  tile_status_bits_parm         := 0

  'Start Drivers /////////////////////////////////////////////////////////////////////////////////

  'start the mouse
  mouse.start(2)                                        'ps/2 mouse on pins 8-11

  'start the keyboard
  keyboard.start(3)                                     'ps/2 keyboard on pins 12-15
  
  'start the graphics engine
  gfx.start(@tile_map_base_ptr_parm)

  'start random number generator
  rr.start 

  'Intro loop /////////////////////////////////////////////////////////////////////////////////
  Intro 
  
  'Start Game /////////////////////////////////////////////////////////////////////////////////

  'disable sprites
  sprites[0] := $00
  sprites[2] := $00
  sprites[4] := $00

  'make starting puzzle
  Make

  'copy game tilemap
  repeat n from 0 to 191
    activetilemap[n]:=tile_map[n]

  'draw grid, set poss
  repeat x from 0 to 8
    repeat y from 0 to 8
      DrawCell(x,y)
      CheckCell(x,y)

  'position cell cursor
  cellx:=4
  celly:=4
  
  'mouse sprite
  sprites[3] := @mousesprite

  'box cursor sprite
  sprites[1] := @boxsprite
      
  ' Main Loop /////////////////////////////////////////////////////////////////////////////////
  repeat

    '///////////////////////////////////////////////////////////////////
    'draw
  
    'draw mouse
    sprites[2] :=(mousey<<24)+(mousex<<16)+1

    'draw cell highlight
    sprites[0]:=((celly+1)<<28)+((cellx+1)<<20)+1

    'draw possibles bar
    DrawCellPoss(cellx,celly)

    '///////////////////////////////////////////////////////////////////
    'mouse

    'mouse position
    mousex:=mouse.abs_x
    mousey:=-mouse.abs_y

    'select cell - lmb
    if mouse.button(0)==true

      tempcellx:=mousex>>4                              'is x in bounds                                            
      if tempcellx=>1                                                            
        if tempcellx=<9

          tempcelly:=mousey>>4                          'is y in bounds                                                      
          if tempcelly=>1                                                            
            if tempcelly=<9

              cellx:=tempcellx-1                        'select cell
              celly:=tempcelly-1              
              i:=(celly*9)+cellx

     '///////////////////////////////////////////////////////////////////
    'keyboard

    'get keypress
    k:=keyboard.key

    'do cell set if number key pressed
    if k>$30
      if k<$3A
        if GridLock[i]==0                        
          SetCell(cellx,celly,k-$30,0)
          DrawCell(cellx,celly)
          CheckGrid      

    'do cell clear if backspace key pressed
    if k==$C8
      if GridLock[i]==0                        
        SetCell(cellx,celly,0,0)
        DrawCell(cellx,celly)
        CheckGrid
       
    'toggle lock if L key pressed
    if k==$6C
      if Grid[i]>0
        GridLock[i]:=1-GridLock[i]
        DrawCell(cellx,celly)

    'solve if S key pressed 
    if k==$73
      Solve
      repeat x from 0 to 8
        repeat y from 0 to 8
          DrawCell(x,y)

    'make new if N key pressed 
    if k==$6E
      Make
      repeat x from 0 to 8
        repeat y from 0 to 8
          DrawCell(x,y)
       
    'restart grid if R key pressed 
    if k==$72
      repeat x from 0 to 8
        repeat y from 0 to 8
          i:=(y*9)+x
          if GridLock[i]==0
            Grid[i]:=0
            DrawCell(x,y)
      CheckGrid

    'clear grid if C key pressed 
    if k==$63
      repeat x from 0 to 8
        repeat y from 0 to 8
          i:=(y*9)+x
          GridLock[i]:=0
          Grid[i]:=0
          DrawCell(x,y)
      CheckGrid

pri Intro | n,cuccox[3],cuccoy[3],angle',frame

  cuccox[0]:=0                                         'position sprites
  cuccox[1]:=50
  cuccox[2]:=100

  sprites[1] := @cuccosprite                 'flying cucco sprites                     
  sprites[3] := @cuccosprite
  sprites[5] := @cuccosprite

  repeat n from 0 to 191                                'make intro tilemap
    activetilemap[n]:=$0D_00

  repeat n from 0 to 5                                  'print "sudoku" in the middle of the screen
    activetilemap[n+82]:=$0C_00+n+11

  activetilemap[176]:=$0D_00+majorversion               'print version number
  activetilemap[177]:=$0D_00+minorversion

  'Intro Loop    
  repeat
    repeat n from 0 to 800
      if mouse.button(0)==true                            'exit intro if lmb                        
        return    
      if keyboard.key>0                                   'exit intro if key
        return

    cuccox[0]++                                         'move across screen
    cuccox[0]++
    cuccox[1]++
    cuccox[2]++

    angle:=angle+5                                      'progress angle                        

    cuccoy[0]:=58+(Trig.Sin(Trig.DEG2PROP(Angle))~>11)  '50 +/- 32
    cuccoy[1]:=96+(Trig.Sin(Trig.DEG2PROP(Angle+90))~>10)  '100 +/- 64
    cuccoy[2]:=150+(Trig.Sin(Trig.DEG2PROP(Angle+180))~>11)  '150 +/- 32

    if cuccox[0]>176                        'boundry                        
      cuccox[0]:=0
    if cuccox[1]>176
      cuccox[1]:=0
    if cuccox[2]>176
      cuccox[2]:=0
{
    frame:=1-frame

    if frame:=0
      sprites[1] := @cuccosprite                 'flying cucco sprites                     
      sprites[3] := @cuccosprite
      sprites[5] := @cuccosprite
    if frame:=1
      sprites[1] := @cuccosprite2                'flying cucco sprites                     
      sprites[3] := @cuccosprite2
      sprites[5] := @cuccosprite2
}        
      
      
    sprites[0] :=(cuccoy[0]<<24)+(cuccox[0]<<16)+1      'draw sprites
    sprites[2] :=(cuccoy[1]<<24)+(cuccox[1]<<16)+1
    sprites[4] :=(cuccoy[2]<<24)+(cuccox[2]<<16)+1
             
PUB Make | x,y,i,j
''Generate a new puzzle in Grid[]

  'clear
  repeat x from 0 to 8
    repeat y from 0 to 8
      i:=(y*9)+x
      Grid[i]:=0    

  'solve until done
  repeat
    if Solve==1
      quit

  'blank some squares
  repeat j from 1 to 53
   
    x:=||rr.random//9
    y:=||rr.random//9
    i:=(y*9)+x
    if Grid[i]==0
      j--        
    GridLock[i]:=0
    Grid[i]:=0

  repeat x from 0 to 8
    repeat y from 0 to 8
      i:=(y*9)+x
      if Grid[i]>0
        GridLock[i]:=1
      CheckCell(x,y)
    
PUB Solve | newcellsolved,x,y,i,n,lives
''Automatically solves Sudoku in Grid[]

  lives:=10
  level:=1

  'Store starting grid
  repeat x from 0 to 8
    repeat y from 0 to 8
      i:=(y*9)+x
      OriginalGrid[i]:=Grid[i]
      OriginalGrid[i+81]:=GridLock[i]
      
      'display grid while we're at it
'      DrawCell(x,y)
      'check grid posibilities too
      CheckCell(x,y)

  repeat
    'solve!
    newcellsolved:=0
    repeat x from 0 to 8
      repeat y from 0 to 8
     
        i:=(y*9)+x
        
        'if empty
        if Grid[i]==0
          'check level of cell
          if GridPoss[i]==level
          
            'fill cell
            n:=SolveCell(x,y)

            'update graphics
            'DrawCell(x,y)

            'update surrounding cells' possibilities
            UpdateNeighbors(x,y,n)

            'decrement level
            newcellsolved:=1
            level--
            if level==0
              level:=1            
                

    'no cells at current level - increase
    if newcellsolved==0
      level++
      'no cells solveable
      if level==10            

        'check if won
        if ValidateGrid==1
          return 1        

        'lose, retart
        level:=1
        'restore starting grid
        repeat x from 0 to 8
          repeat y from 0 to 8
            i:=(y*9)+x
            Grid[i]:=OriginalGrid[i]
            GridLock[i]:=OriginalGrid[i+81]
'            DrawCell(x,y)
        CheckGrid

        'lose a life
        lives--
        'give up
        if lives==0
          return 0  
         
pri SolveCell(x,y) | randomnumber,i,n
'Fill in Cell (x,y) with number picked randomly from possible pool

  randomnumber:=||rr.random//level
  randomnumber++

  i:=(y*9)+x
    
  repeat n from 1 to 9                                   'loop numbers
    if GridPoss[(n*81)+i]==0                             'if possible
      if --randomnumber==0                               'and count down (random) finished
        SetCell(x,y,n,0)                                   'put number in cell cell
        return n
        
pri CheckGrid | cx,cy
'Check levels for whole grid
     
  'old cell update
  repeat cx from 0 to 8
    repeat cy from 0 to 8
      CheckCell (cx,cy)

pri CheckCell (x,y) | cx,cy,n,i,boxx,boxy
'Check possibilities for cell (x,y) and set level

  i:=(y*9)+x                                            'index

  repeat n from 1 to 9                                  'blank possibilities for this cell
    GridPoss[(n*81)+i]:=0

  'check dependant cells to find possibilities
  'row
  repeat cx from 0 to 8                                 'loop row
    if cx<>x                                            'not same cell
      n:=Grid[(y*9)+cx]                                 'get number in cell
      if n>0                                            'is there one?
        Gridposs[(n*81)+i]:=1                           'set possibilities
        
  'column
  repeat cy from 0 to 8                                 'loop column
    if cy<>y                                            'not same cell
      n:=Grid[(cy*9)+x]                                 'get number in cell
      if n>0                                            'is there one?
        Gridposs[(n*81)+i]:=1                           'set possibilities

  'box
  boxx:=(x/3)*3                                         'find box
  boxy:=(y/3)*3

  repeat cx from boxx to boxx+2                         'loop box
    repeat cy from boxy to boxy+2
      if cx<>x                                          'not same column
        if cy<>y                                        'not same row
          n:=Grid[(cy*9)+cx]                            'get number in cell
          if n>0                                        'is there one?
            Gridposs[(n*81)+i]:=1                       'set possibilities

  'update cell level
  GridPoss[i]:=9                                        'level 9 is all possible
  repeat n from 1 to 9                                  'loop numbers
    if GridPoss[(n*81)+i]>0                             'if already present
      GridPoss[i]--                                     'decrement cell level

pri UpdateNeighbors(x,y,n) | cx,cy,boxx,boxy
'Fast update level of dependant cells after cell (x,y) adds number n
     
  'row
  repeat cx from 0 to 8                                 'loop row
    if Grid[(y*9)+cx]==0                                'cell empty 
      if cx<>x                                          'not same cell
        UpdateCell(cx,y,n)                              'update cell
   
  'column    
  repeat cy from 0 to 8                                 'loop column
    if Grid[(cy*9)+x]==0                                'cell empty 
      if cy<>y                                          'not same cell
        UpdateCell(x,cy,n)                              'update cell
   
  'box
  boxx:=(x/3)*3                                         'find box
  boxy:=(y/3)*3
  repeat cx from boxx to boxx+2                         'loop box
    repeat cy from boxy to boxy+2
      if Grid[(cy*9)+cx]==0                             'cell empty 
        if cx<>x                                        'not same column
          if cy<>y                                      'not same row
            UpdateCell(cx,cy,n)                         'update cell

pri UpdateCell (x,y,n) | i,ni
'Fast update cell (x,y) level after addition of number n in dependant cell

  i:=(y*9)+x                                            'index
  ni:=(n*81)+i

  if Grid[i]==0                                         'if cell empty                                                
    if GridPoss[ni]==0                                  'if was not already present
      GridPoss[ni]:=1                                   'set present
      GridPoss[i]--                                     'decrement level
      
  
PRI SetCell(x,y,n,l) | i
'Set cell at (x,y) to number n and lock if l
  i:=(y*9)+x
  Grid[i]:=n
  Gridlock[i]:=l

pri ValidateGrid | x,y,i,total
'check if grid solved ok 

  CheckGrid

  repeat x from 0 to 8
    repeat y from 0 to 8
    
      i:=(y*9)+x

      
      total:=total+Grid[i]                              'count total
                                      
      if GridPoss[i]<>1                                 'more/less than one possibility
        return 0
      
      if GridPoss[(Grid[i]*81)+i]>0                     'fill doesn't match that possibility
        return 0

  if total<>405                                         'the magic number 1*9 + 2*9 + ... 9*9
  
  'success
  return 1
            
  
PRI DrawCell(x,y) | i,j
'Update Cell on HEL_GFX tilemap

  'grid index
  i:=(y*9)+x
  'tilemap index
  j:=(y*16)+x
  
  'keep palette intact, replace number
  activetilemap[j]:=(tile_map[j]&$FF00) + Grid[i]

  'change palette to hilight locked cells if so
  if Gridlock[i]==1
    activetilemap[j]:=activetilemap[j]+$02_00

PRI DrawCellPoss(x,y) | i,n,j
'Update display of which numbers are possible on HEL_GFX tilemap

  i:=(y*9)+x

  repeat n from 1 to 9
    j:=159+n
    if GridPoss[(n*81)+i]==0
      if Grid[i]==n
        activetilemap[j]:=(tile_map[j]&$FF00)+n+$02_00  'hilight current (ok)
      else
        activetilemap[j]:=(tile_map[j]&$FF00)+n         'possible
    else
      if Grid[i]==n
        activetilemap[j]:=(tile_map[j]&$FF00)+n+$03_00  'hilight current (warning!)
      else
        activetilemap[j]:=(tile_map[j]&$FF00)+n+$01_00    'not possible
       
DAT

' Map tiles /////////////////////////////////////////////////////////////////////////////////

tile_map      word      $01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$04_0a,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $01_00,$01_00,$01_00,$00_00,$00_00,$00_00,$01_00,$01_00,$01_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $07_00,$0C_11,$07_0b,$07_0c,$07_0d,$07_0e,$07_0f,$07_10,$07_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $08_00,$08_00,$08_00,$08_00,$08_00,$08_00,$08_00,$08_00,$08_00,$04_00,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0
              word      $06_0a,$05_00,$05_00,$05_00,$05_00,$05_00,$05_00,$05_00,$05_00,$05_0a,$00_01,$00_01,$00_01,$00_01,$00_01,$00_01 ' row 0

' Tile bitmaps /////////////////////////////////////////////////////////////////////////////////

tile_bitmaps

'22 Feb 2007 18:46:29
'sprite converter 0.01 - (c) flying cucco

'_.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'1.bmp
Long %%0000000000000000 
Long %%0000000000000000
Long %%0000000011000000
Long %%0000000011100000
Long %%0000000011110000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000011000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'2.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0001100000000000
Long %%0001100000000000
Long %%0001110000000000
Long %%0000111100000000
Long %%0000001111000000
Long %%0000000011110000
Long %%0000000000111100
Long %%0000000000001110
Long %%0001111111111110
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'3.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0001100000000000
Long %%0001100000000000
Long %%0001110000000000
Long %%0000111111111000
Long %%0001110000000000
Long %%0001100000000000
Long %%0001100000000000
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'4.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000001100000110
Long %%0000001100000110
Long %%0000001100000110
Long %%0000001100000110
Long %%0000001100001110
Long %%0001111111111100
Long %%0000001100000000
Long %%0000001100000000
Long %%0000001100000000
Long %%0000001100000000
Long %%0000001100000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'5.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0001111111111110
Long %%0000000000000110
Long %%0000000000000110
Long %%0000000000000110
Long %%0000000000000110
Long %%0000111111111110
Long %%0001110000000000
Long %%0001100000000000
Long %%0001100000000000
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'6.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0000000000000110
Long %%0000000000000110
Long %%0000000000000110
Long %%0000111111111110
Long %%0001110000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'7.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0001111111111110
Long %%0001100000000000
Long %%0001100000000000
Long %%0000110000000000
Long %%0000110000000000
Long %%0000011000000000
Long %%0000011000000000
Long %%0000001100000000
Long %%0000001100000000
Long %%0000000110000000
Long %%0000000110000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'8.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0001110000001110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'9.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000001110
Long %%0001111111111100
Long %%0001100000000000
Long %%0001100000000000
Long %%0001100000000000
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'Box corner.bmp
Long %%1111111111111111
Long %%1111111111111110
Long %%1111111111111100 
Long %%1111111111111000 
Long %%1111111111110000
Long %%1111111111100000
Long %%1111111111000000
Long %%1111111110000000
Long %%1111111100000000
Long %%1111111000000000
Long %%1111110000000000
Long %%1111100000000000
Long %%1111000000000000
Long %%1110000000000000
Long %%1100000000000000
Long %%1000000000000000

's.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0000000000001110
Long %%0000111111111100
Long %%0001110000000000
Long %%0001100000000000
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'u.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'd.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0001100000000000
Long %%0001100000000000
Long %%0001100000000000
Long %%0001111111111100
Long %%0001100000001110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'o.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000111111111100
Long %%0001110000001110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'k.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000110
Long %%0000000000000110
Long %%0000000000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000000110
Long %%0000111111111110
Long %%0001110000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

'u.bmp
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001100000000110
Long %%0001110000001110
Long %%0000111111111100
Long %%0000000000000000
Long %%0000000000000000
Long %%0000000000000000

' Sprite Bitmaps ///////////////////////////////////////////////////////////////////////////////// 

'flyingcucco_16.bmp
cuccosprite   Long %%0022022200000000
              Long %%0212222200222000
              Long %%0222222000233200
              Long %%0222222222113320
              Long %%0212131211111320
              Long %%0222323211111320
              Long %%2112131211122200
              Long %%2312222111111200
              Long %%2122221111111120
              Long %%2223222111111112
              Long %%0023322311111212
              Long %%0021333331111122
              Long %%0002133332111120
              Long %%0000222222222220
              Long %%0002312333122000
              Long %%0002222222220000
               
              Long %%0011011100000000
              Long %%0111111100111000
              Long %%0111111000111100
              Long %%0111111111111110
              Long %%0111111111111110
              Long %%0111111111111110
              Long %%1111111111111100
              Long %%1111111111111100
              Long %%1111111111111110
              Long %%1111111111111111
              Long %%0011111111111111
              Long %%0011111111111111
              Long %%0001111111111110
              Long %%0000111111111110
              Long %%0001111111111000
              Long %%0001111111110000
{              
cuccosprite2  Long %%0022022200000000
              Long %%0212222200222000
              Long %%0222222000233200
              Long %%0222222222113320
              Long %%0212131211122222
              Long %%0222323211211112
              Long %%2112131212111112
              Long %%2312222112111112
              Long %%2122221111111122
              Long %%2223222111111122
              Long %%0023322311112200
              Long %%0021333331112000
              Long %%0002133332112000
              Long %%0000222222222000
              Long %%0002312333120000
              Long %%0002222222220000

              Long %%0011011100000000
              Long %%0111111100111000
              Long %%0111111000111100
              Long %%0111111111111110
              Long %%0111111111111111
              Long %%0111111111111111
              Long %%1111111111111111
              Long %%1111111111111111
              Long %%1111111111111111
              Long %%1111111111111111
              Long %%0011111111111100
              Long %%0011111111111000
              Long %%0001111111111000
              Long %%0000111111111000
              Long %%0001111111110000
              Long %%0001111111110000
}              
'boxborder.bmp
boxsprite     Long %%2222200000022222
              Long %%2222200000022222
              Long %%2200000000000022
              Long %%2200000000000022
              Long %%2200000000000022
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%2200000000000022
              Long %%2200000000000022
              Long %%2200000000000022
              Long %%2222200000022222
              Long %%2222200000022222               

              Long %%1111100000011111
              Long %%1111100000011111
              Long %%1100000000000011
              Long %%1100000000000011
              Long %%1100000000000011
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%0000000000000000
              Long %%1100000000000011
              Long %%1100000000000011
              Long %%1100000000000011
              Long %%1111100000011111
              Long %%1111100000011111               

'cursor.bmp
mousesprite   Long %%0000000000022222
              Long %%0000000222222222
              Long %%0002222222233322
              Long %%2222222333333322
              Long %%0222333333333322
              Long %%0022233333333220
              Long %%0002223333333220
              Long %%0000222333333220
              Long %%0000222233333220
              Long %%0002222223332200
              Long %%0022222222332200
              Long %%0222222222232200
              Long %%2222222002222200
              Long %%2222220000222000
              Long %%0222200000022000
              Long %%0022000000002000
               
              Long %%0000000000011111
              Long %%0000000111111111
              Long %%0001111111111111
              Long %%1111111111111111
              Long %%0111111111111111
              Long %%0011111111111110
              Long %%0001111111111110
              Long %%0000111111111110
              Long %%0000111111111110
              Long %%0001111111111100
              Long %%0011111111111100
              Long %%0111111111111100
              Long %%1111111001111100
              Long %%1111110000111000
              Long %%0111100000011000
              Long %%0011000000001000
               
' Palettes ///////////////////////////////////////////////////////////////////////////////// 
palettes

{
  COL_Black       = %0000_0010  02
  COL_DarkGrey    = %0000_0011  03
  COL_Grey        = %0000_0100  04
  COL_LightGrey   = %0000_0101  05
  COL_BrightGrey  = %0000_0110  06
  COL_White       = %0000_0111  07
  
  COL_PowerBlue   = %1111_1_100 FC
  COL_Blue        = %1110_1_100 EC
  COL_SkyBlue     = %1101_1_100 DC
  COL_AquaMarine  = %1100_1_100 CC
  COL_LightGreen  = %1011_1_100 BC
  COL_Green       = %1010_1_100 AC
  COL_GreenYellow = %1001_1_100 9C
  COL_Yellow      = %1000_1_100 8C
  COL_Gold        = %0111_1_100 7C
  COL_Orange      = %0110_1_100 6C
  COL_Red         = %0101_1_100 5C
  COL_VioletRed   = %0100_1_100 4C
  COL_Pink        = %0011_1_100 3C
  COL_Magenta     = %0010_1_100 2C
  COL_Violet      = %0001_1_100 1C
  COL_Purple      = %0000_1_100 0C
}

'                    color 03_02_01_00
pal_00{red}          long $6d_6b_02_3e
pal_01{blue}         long $6d_6b_02_ee
pal_02{red-res}      long $6d_6b_3b_3d
pal_03{blue-res}     long $6d_6b_eb_ed
pal_04{border1}      long $6d_6b_02_8e
pal_05{border2}      long $6d_6b_8e_8c
pal_06{border3}      long $6d_6b_8c_02
pal_07{white}        long $6d_6b_02_07
pal_08{white-grn}    long $6d_6b_ab_AD
pal_09{white-red}    long $6d_6b_5b_5D
pal_0A{white-cur}    long $6d_6b_07_AB
pal_0B{white-cur}    long $6d_6b_07_5B
pal_0C{cucco}        long $05_02_ec_07
pal_0D{cucco-blk}    long $05_02_ec_7e